# -*- coding: utf-8 -*-
# pylint: disable=missing-module-docstring
from typing import Literal

ConfiguracaoEventoTipo = Literal[
    'VENCIMENTO',
    'DESCONTO',
    'INFORMATIVO_MAIS',
    'INFORMATIVO_MENOS',
]

ConfiguracaoEventoClassificacao = Literal[
    'AVPREINDUMDOZE',
    'ADI13SAL',
    'AVPREIND13SAL',
    'INTEG13SAL',
    'RPPSABAT13',
    'RPPSABAT',
    'ABATSALM13',
    'ABATSALM',
    'ADIFERIAS',
    'ADISALNDESC',
    'AUXNAT',
    'AVPREDESC',
    'AVPREIND',
    'BASABATINSSDV',
    'BASINSSDV',
    'BASINSSDV13SAL',
    'BASINSSOUTEMP13SAL',
    'BASINSSOUTEMP',
    'BASIRRFDV',
    'BASIRRFDV13SAL',
    'BASIRRFFERIASANT',
    'BASIRRFFERIASRESCDV',
    'BASIRRFOUTEMP13SAL',
    'BASIRRFOUTEMP',
    'DESCHAUXMAT13SAL',
    'DESCHAUXMAT',
    'DESC13SALADI',
    'DESCADISAL',
    'DESC13SALDEVREINTG',
    'DESCDEP',
    'DEVINSS',
    'DEVIRRF',
    'DEVFGTS',
    'EMPRESTIMO',
    'FALTADSR',
    'FALTAS',
    'FGTS13SAL',
    'FGTSAVPRE',
    'FGTSMESANT',
    'FGTSSOBFERIAS',
    'FGTS',
    'FUNDASS13SAL',
    'FUNDASS',
    'FUNDFIN13SAL',
    'FUNDFIN',
    'FUNDPREV13SAL',
    'FUNDPREV',
    'HAUXMATNPAG',
    'INSS13SAL',
    'INSSSOBHAUXMATNPAG',
    'INSS',
    'IRRF13SAL',
    'IRRFFERIASRESC',
    'IRRF',
    'ISS',
    'MULTAFGTS',
    'NENHUMA',
    'PARCISENIRRFMOLGRVFERIASADI',
    'PARCISENIRRFMOLGRVFERIASRESC',
    'PARCISENFUNDFIN13SAL',
    'PARCISENFUNDFIN',
    'PARCISENFUNDPREV13SAL',
    'PARCISENFUNDPREV',
    'PARCISENIRRF13SAL',
    'PARCISENIRRFMOLGRV13SAL',
    'PARCISENIRRFMOLGRVFERIAS',
    'PARCISENIRRFMOLGRV',
    'PARCISENIRRFSOBFERIASRESC',
    'PARCISENIRRF',
    'PENSJUDDESC',
    'PLANOSAUDE',
    'PREVESTDECSAL',
    'PREVEST',
    'PROCEDMED',
    'PONTIDAO',
    'PRORROGAUXMAT11770',
    'REDBASINSSTRANSPAUT',
    'REDBASIRRFTRANSPAUT',
    'SALFAMAPOS',
    'SALFAMCEL',
    'SALFAMESP',
    'SALFAMEST',
    'SALFAMPAGMAIOR',
    'SENAT',
    'SEST',
    'SOBREAVISO',
    'VALETRANSP',
    'HORASFERIAS',
    'FERIASADI',
    'HORASFERIASCOL',
    'HORASFERIASAVPREVIND',
    'FERIASTERCO',
    'ABONOTERCO',
    'FERDOBROTERCO',
    'FERINDENTERCO',
    'FERPROPTERCO',
    'FERVENCTERCO',
    'BASEINSSNEG',
    'AUXDOENCA15DIAS',
    'ABATINSSFER',
    'ABATFUNDOPREVIDENCIAFER',
    'ABATPREVIDENCIAESTADUALFER',
    'ABATFUNDOFINANCEIROFER',
    'ABATFUNDOASSISTENCIAFER',
    'LIQ13SALINTEGADI',
    'TOTDESC13SALINTEGADI',
    'DESC13SALINTEGADI',
    'DESC13SALINTEGADIESOCIAL',
    'JUROSMORA',
    'AUXMATERNIDADE13',
    'PENSAOALIMENTICIA',
    'BASIRRFRRA',
    'DEDUCSIMPLIRRFMENSAL',
    'DEDUCCOMPLIRRFMENSAL',
    'DEDUCSIMPLIRRF13',
    'DEDUCCOMPLIRRF13',
    'BASINSSOUTEMPAUTONOMO13SAL',
    'BASINSSOUTEMPAUTONOMO',
    'PREVCOMPL',
    'PREVCOMPL13SAL',
    'REEMBDESPSAUDE'
]

FolhaSituacao = Literal[
    'PENDENTE',
    'CALCULADA',
    'FECHADA',
    'ERRO',
    'LANCADA'
]

FolhaTipoProcessamento = Literal[
    'MENSAL',
    'DECIMO_TERCEIRO_SALARIO',
    'RESCISAO',
    'FERIAS',
    'PAGAMENTO_ANTERIOR'
]

FolhaSubTipoProcessamento = Literal[
    'ADIANTAMENTO',
    'INTEGRAL',
    'COMPLEMENTAR'
]

TipoBaseClassificacao = Literal[
    'ABATIMENTO_INSS_13_SALARIO',
    'ABATIMENTO_INSS_FERIAS',
    'ABATIMENTO_INSS',
    'ABATIMENTO_IRRF_13_SALARIO',
    'ABATIMENTO_IRRF_FERIAS',
    'ABATIMENTO_IRRF',
    'BASE_MARGEM_CONSIGNAVEL',
    'COMPOEM_HORAS_DO_MES',
    'CONTRIB_SINDICAL_ANUAL',
    'DESC_13_SALARIO_REINTEGRACAO',
    'DESCONTO_IRRF_13_SALARIO',
    'DESCONTO_IRRF_FERIAS_RESC',
    'DESCONTO_IRRF_FERIAS',
    'DESCONTO_IRRF',
    'DESCONTO_UM_TERCO_DE_FERIAS',
    'EXCEDENTE_INSS_13_SALARIO',
    'EXCEDENTE_INSS_FERIAS',
    'EXCEDENTE_INSS',
    'EXCESSO_DA_MARGEM_CONSIGNAVEL',
    'FGTS_13_SALARIO',
    'FGTS_AVISO_PREVIO',
    'FGTS_FERIAS',
    'FGTS',
    'FUNDO_ASSISTENCIA_13_SALARIO',
    'FUNDO_ASSISTENCIA_FERIAS',
    'FUNDO_ASSISTENCIA',
    'FUNDO_FINANCEIRO_13_SALARIO',
    'FUNDO_FINANCEIRO_FERIAS',
    'FUNDO_FINANCEIRO',
    'FUNDO_PREVIDENCIA_13_SALARIO',
    'FUNDO_PREVIDENCIA_FERIAS',
    'FUNDO_PREVIDENCIA',
    'HORAS_EXTRAS',
    'INSS_13_SALARIO',
    'INSS_FERIAS',
    'INSS_OUTRAS_EMP_13_SAL',
    'INSS_OUTRAS_EMPRESAS',
    'INSS',
    'IRRF_13_SALARIO',
    'IRRF_FERIAS_RESCISAO',
    'IRRF_FERIAS',
    'IRRF_OUTRAS_EMP_13_SAL',
    'IRRF_OUTRAS_EMPRESAS',
    'IRRF',
    'MEDIA_AUXILIO_MATERNIDADE_PROPORCIONAL',
    'MEDIA_AUXILIO_MATERNIDADE',
    'OUTRAS_BASES',
    'PAGA_PROPORCIONAL',
    'PERICULOSIDADE',
    'PREV_ESTADUAL_13_SALARIO',
    'PREV_ESTADUAL_FERIAS',
    'PREV_ESTADUAL',
    'SALARIO_BASE',
    'SALARIO_FAMILIA_NORMAL',
    'SALDO_DA_MARGEM_CONSIGNAVEL',
    'SINDICATO',
    'UM_TERCO_FERIAS_VENCIDAS_RESC',
    'VALOR_DA_MARGEM_CONSIGNAVEL',
    'DEVOLUCAO_IRRF',
    'DEVOLUCAO_INSS',
    'IRRF_RRA',
    'DEDUC_IRRF_MENSAL',
    'DEDUC_IRRF_13',
    'INSS_OUTRAS_EMP_AUTONOMO_13_SAL',
    'INSS_OUTRAS_EMPRESAS_AUTONOMO'
]

MatriculaTipo = Literal[
    'FUNCIONARIO',
    'ESTAGIARIO',
    'AUTONOMO',
    'APOSENTADO',
    'PENSIONISTA',
]

ConcursoProcessoSeletivoProcesso = Literal[
    'COMPLETO',
    'SIMPLIFICADO',
    'NULO'
]

ConcursoProcessoSeletivoRegimeJuridico = Literal[
    'CLT',
    'ESTATUTARIO',
    'MISTO',
    'NULO'
]

ConcursoProcessoSeletivoResponsavelExecucao = Literal[
    'OUTRA_UNIDADE_GESTORA',
    'PRESTADORA_SERVICO_COM_CONTRATO',
    'PRESTADORA_SERVICO_SEM_CONTRATO',
    'PROPRIA_UNIDADE_GESTORA',
    'NULO'
]

ConcursoProcessoSeletivoSituacaoConcursoProcessoSeletivo = Literal[
    'EM_ABERTO',
    'ENCERRADO',
    'INSCRICOES_ABERTAS',
    'INSCRICOES_FECHADAS',
    'PERIODO_CLASSIFICATORIO',
    'PERIODO_CONVOCATORIO',
    'REALIZACAO_AVALIACOES',
    'NULO'
]

ConcursoProcessoSeletivoTipoAvaliacao = Literal[
    'PROVAS',
    'PROVAS_TITULOS',
    'TITULOS',
    'NULO'
]

ConcursoProcessoSeletivoTipoProcessoAvaliacao = Literal[
    'AUTOMATICO',
    'MANUAL',
    'NULO'
]

ConcursoProcessoSeletivoTipoRecrutamento = Literal[
    'CONCURSO_PUBLICO',
    'PROCESSO_SELETIVO',
    'NULO'
]

TipoAtoClassificacao = Literal[
    'ATA',
    'ATA_POSSE',
    'ATO',
    'ATO_ADMINISTRATIVO',
    'ATO_COMISSAO_EXEC_LEGIS',
    'ATO_CONSELHO_DELIBERATIVO',
    'ATO_CONSELHO_FISCAL',
    'ATO_CONSORCIO',
    'COMUNICACAO_INTERNA',
    'CONCESSAO_AFAST_INTER_PARTICULAR',
    'CONSTITUICAO',
    'CONTRATO',
    'CONVENIO',
    'DECRETO',
    'DECRETO_LEGISLATIVO',
    'DECRETO_LEI',
    'DELIBERACAO',
    'DESPACHO',
    'EDITAL',
    'EMENDA',
    'EMENDA_CONSTITUCIONAL',
    'EMENDA_MODIFICATIVA',
    'ESTATUTO_SOCIAL',
    'IMAGEM_EXEMPLAR_PUBLICA_ORGAO_OFICIAL',
    'INSTRUCAO',
    'JUSTIFICATIVA_CANCELAMENTO_INTERVENCAO',
    'LEI',
    'LEI_AUTORIZATIVA',
    'LEI_COMPLEMENTAR',
    'LEI_CRIACAO',
    'LEI_MUNICIPAL',
    'LEI_ORDINARIA',
    'LEI_ORGANICA',
    'MEDICAO',
    'MEDIDA_PROVISORIA',
    'MEMORANDO',
    'MULTIMIDIA',
    'OFICIO',
    'ORCAMENTO',
    'ORCAMENTO_BASE',
    'PARECER',
    'PLANILHA_ORCAMENTARIA_ADITIVO',
    'PLANILHA_ORCAMENTARIA_CONTRATADA',
    'PORTARIA',
    'PROCESSO',
    'PROCESSO_JUDICIAL',
    'PROJETO',
    'REGIMENTO_INTERNO',
    'REGISTRO_IMOVEIS',
    'REQUERIMENTO',
    'RESOLUCAO',
    'TERMO_MEDICAO',
    'TERMO_PARALISACAO',
    'TERMO_RECEBIMENTO'
]

MatriculaSituacao = Literal[
    'TRABALHANDO',
    'FALTA',
    'AFASTADO',
    'CEDIDO',
    'SUSPENSO',
    'FERIAS',
    'DEMITIDO',
    'SEM_VINCULO',
    'APOSENTADO',
    'PENSIONISTA',
    'CESSADO',
    'BENEFICIO_SUSPENSO',
    'EM_SERVICO',
    'INATIVO',
]

MatriculaFormaPagamento = Literal[
    'DINHEIRO',
    'CHEQUE',
    'CREDITO_EM_CONTA'
]

MatriculaIndicativoAdmisao = Literal[
    'NORMAL',
    'DECORRENTE_ACAO_FISCAL',
    'DECORRENTE_DECISAO_JUDICIAL',
]

CargoAcumuloCargos = Literal[
    'NAO_ACUMULAVEL',
    'PROFESSOR',
    'PROFISSIONAL_SAUDE',
    'TECNICO_CENTIFICO'
]

CargoContagemEspecial = Literal[
    'APOSENTADORIA_ESPECIAL',
    'MAGISTRADO',
    'MEMBRO_MPU',
    'MEMBRO_TCU',
    'NAO',
    'PROFESSOR',
    'PROFESSOR_ENSINO_SUPERIOR'
]

CargoGrauInstrucao = Literal[
    'ALFABETIZADO',
    'ENSINO_FUNDAMENTAL_ANOS_FINAIS',
    'ENSINO_FUNDAMENTAL_ANOS_INICIAIS',
    'ENSINO_MEDIO',
    'ENSINO_PROFISSIONALIZANTE',
    'ENSINO_SUPERIOR_SEQUENCIAL',
    'GRADUACAO_BACHARELADO',
    'GRADUACAO_LICENCIATURA',
    'GRADUACAO_TECNOLOGIA',
    'NAO_ALFABETIZADO',
    'POS_DOUTORADO_HABILITACAO',
    'POS_DOUTORADO_LIVRE_DOCENCIA',
    'POS_DOUTORADO_NOTORIO_SABER',
    'POS_GRADUACAO_DOUTORADO',
    'POS_GRADUACAO_ESPECIALIZACAO',
    'POS_GRADUACAO_HONORIS_CAUSA',
    'POS_GRADUACAO_MBA',
    'POS_GRADUACAO_MESTRADO'
]

CargoSituacaoGrauInstrucao = Literal[
    'COMPLETO',
    'INCOMPLETO'
]

CargoUnidadePagamento = Literal[
    'DIARISTA',
    'HORISTA',
    'MENSALISTA',
    'OUTROS',
    'QUINZENALISTA',
    'SEMANALISTA',
    'TAREFEIRO'
]

CampoAdicionalFormato = Literal[
    'DATE',
    'DATETIME',
    'TIME',
    'INTEGER',
    'DECIMAL',
    'TEXT',
    'TEXT_AREA',
    'CPF',
    'CNPJ',
    'EMAIL',
    'PHONE',
    'SELECT',
    'SELECT_MULTIPLE'
]
